@@ -1,4 +1,4 @@
-#! /bin/bash
+#! /usr/bin/env bash
 
 if [ ! -f 'build.sh' ]; then
 	echo 'ERROR: This script must be run from the directory it is in' >&2
@@ -20,6 +20,13 @@ OUTDIR="$(pwd)/out"
 INSTDIR="$(pwd)/inst"
 export ITCLVERS SRC SRCURL BUILDDIR OUTDIR INSTDIR
 
+# Set configure options for this sub-project
+LDFLAGS="${KC_ITCL_LDFLAGS}"
+CFLAGS="${KC_ITCL_CFLAGS}"
+CPPFLAGS="${KC_ITCL_CPPFLAGS}"
+LIBS="${KC_ITCL_LIBS}"
+export LDFLAGS CFLAGS CPPFLAGS LIBS
+
 rm -rf 'build' 'out' 'inst'
 mkdir 'build' 'out' 'inst' || exit 1
 
@@ -84,8 +91,8 @@ fi
 	rm -f configure.new
 
 	# Build
-	echo "Running: ./configure --enable-shared --disable-symbols --prefix=\"${INSTDIR}\" --exec-prefix=\"${INSTDIR}\" --with-tcl=\"${TCLCONFIGDIR}\" ${CONFIGUREEXTRA}"
-	./configure --enable-shared --disable-symbols --prefix="${INSTDIR}" --exec-prefix="${INSTDIR}" --with-tcl="${TCLCONFIGDIR}" ${CONFIGUREEXTRA}
+	echo "Running: ./configure --enable-shared --disable-symbols --prefix=\"${INSTDIR}\" --exec-prefix=\"${INSTDIR}\" --libdir=\"${INSTDIR}/lib\" --with-tcl=\"${TCLCONFIGDIR}\" ${CONFIGUREEXTRA}"
+	./configure --enable-shared --disable-symbols --prefix="${INSTDIR}" --exec-prefix="${INSTDIR}" --libdir="${INSTDIR}/lib" --with-tcl="${TCLCONFIGDIR}" ${CONFIGUREEXTRA}
 
 	echo "Running: ${MAKE:-make}"
 	${MAKE:-make} || exit 1
