@@ -1,4 +1,4 @@
-#! /bin/bash
+#! /usr/bin/env bash
 
 if [ ! -f 'build.sh' ]; then
 	echo 'ERROR: This script must be run from the directory it is in' >&2
@@ -20,6 +20,13 @@ PATCHSCRIPTDIR="$(pwd)/patchscripts"
 PATCHDIR="$(pwd)/patches"
 export SRC SRCURL BUILDDIR OUTDIR INSTDIR PATCHSCRIPTDIR PATCHDIR
 
+# Set configure options for this sub-project
+LDFLAGS="${KC_TCL_LDFLAGS}"
+CFLAGS="${KC_TCL_CFLAGS}"
+CPPFLAGS="${KC_TCL_CPPFLAGS}"
+LIBS="${KC_TCL_LIBS}"
+export LDFLAGS CFLAGS CPPFLAGS LIBS
+
 rm -rf 'build' 'out' 'inst'
 mkdir 'build' 'out' 'inst' || exit 1
 
@@ -37,7 +44,7 @@ if [ ! -f "${SRC}" ]; then
 	elif echo "${TCLVERS}" | grep '^fossil_' >/dev/null; then
 		use_fossil='1'
 
-		FOSSILTAG=$(echo "${TCLVERS}" | sed 's/^fossil_//g')
+		FOSSILTAG=$(echo "${TCLVERS}" | sed 's/^fossil_//g;s/_tk=.*$//g')
 	fi
 	export FOSSILTAG
 
@@ -128,7 +135,7 @@ fi
 	cd "${BUILDDIR}" || exit 1
 
 	# Apply patches if needed
-	for patch in "${PATCHDIR}/all"/tcl-${TCLVERS}-*.diff "${PATCHDIR}/${TCLVERS}"/tcl-${TCLVERS}-*.diff; do
+	for patch in "${PATCHDIR}/all"/tcl-${TCLVERS}-*.diff "${PATCHDIR}/all"/tcl-all-*.diff "${PATCHDIR}/${TCLVERS}"/tcl-${TCLVERS}-*.diff; do
 		if [ ! -f "${patch}" ]; then
 			continue
 		fi
@@ -173,8 +180,8 @@ fi
 		# Remove broken pre-generated Makfiles
 		rm -f GNUmakefile Makefile makefile
 
-		echo "Running: ./configure --disable-shared --with-encoding=utf-8 --prefix=\"${INSTDIR}\" ${CONFIGUREEXTRA}"
-		./configure --disable-shared --with-encoding=utf-8 --prefix="${INSTDIR}" ${CONFIGUREEXTRA}
+		echo "Running: ./configure --disable-shared --with-encoding=utf-8 --prefix=\"${INSTDIR}\" --libdir=\"${INSTDIR}/lib\" ${CONFIGUREEXTRA}"
+		./configure --disable-shared --with-encoding=utf-8 --prefix="${INSTDIR}" --libdir="${INSTDIR}/lib" ${CONFIGUREEXTRA}
 
 		echo "Running: ${MAKE:-make}"
 		${MAKE:-make} || continue
